==> haskell-hit-0.6.3-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-6Cfv7Frt93eGqoUDjBGm2K
key: hit-0.6.3-6Cfv7Frt93eGqoUDjBGm2K
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.Git Data.Git.Types Data.Git.Storage Data.Git.Storage.PackIndex
    Data.Git.Storage.Pack Data.Git.Storage.Object
    Data.Git.Storage.Loose Data.Git.Named Data.Git.Delta Data.Git.Ref
    Data.Git.Revision Data.Git.Repository Data.Git.Diff
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: 7225f0c0e386ea2e6880a2f82401e50e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/hit-0.6.3
hs-libraries: HShit-0.6.3-6Cfv7Frt93eGqoUDjBGm2K
depends:
    attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-AfAYzYlQSOMK4KXYULV7yM
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    system-fileio-0.3.16.3-EDef2a4Ximk1z04PLLp95q
    system-filepath-0.4.13.4-24DUGoIUqZu3MxGDhYLfCN
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
    zlib-bindings-0.1.1.5-C86Zxl67C8Q9nWCJyZSi5q
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hit-0.6.3-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-BuGxbq6QqmqzvG0JPF0RE
key: hit-0.6.3-BuGxbq6QqmqzvG0JPF0RE
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.Git Data.Git.Types Data.Git.Storage Data.Git.Storage.PackIndex
    Data.Git.Storage.Pack Data.Git.Storage.Object
    Data.Git.Storage.Loose Data.Git.Named Data.Git.Delta Data.Git.Ref
    Data.Git.Revision Data.Git.Repository Data.Git.Diff
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: afa40bae41ecf73a3f492f1792e8ad84
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/hit-0.6.3
hs-libraries: HShit-0.6.3-BuGxbq6QqmqzvG0JPF0RE
depends:
    attoparsec-0.13.1.0-2DLGgk6uYI0KCQbpcUzmmN base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-E1hIynbSeej7VAW0TGWaxE
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    system-fileio-0.3.16.3-EDef2a4Ximk1z04PLLp95q
    system-filepath-0.4.13.4-24DUGoIUqZu3MxGDhYLfCN
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
    zlib-bindings-0.1.1.5-C86Zxl67C8Q9nWCJyZSi5q
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
